@@ -1,8 +1,19 @@
+from tkinter import N
 import sympy as sy
 import IPython
 
-def Inicializar():
-  global DatosList,Orden
+def Inicializar(n):
+  global DatosList,Orden,Estilo
+
+  if  n ==1:
+    Estilo = "textrm"#roman
+  elif n ==2:
+    Estilo = "textbf"#bold
+  elif n ==3:
+    Estilo = "texttt"#typewriter
+  elif n == 5:
+    Estilo = "textit"#italic
+
   DatosList = []
   Orden = 8
   return DatosList,Orden
@@ -29,13 +40,13 @@ def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que
   
   if Tipo == "Ecuacion":#Si hemos identificado el elemento ingresado como una ecuación, entonces la imprimimos en rojo
     texto = sy.latex(elemento.args[0]) + "=" + sy.latex(elemento.args[1])
-    IPython.display.display(IPython.display.Latex(r"\textcolor{"+str(color)+"}{"+texto+"}"))
+    IPython.display.display("\\"+Estilo+"{"+IPython.display.Latex(r"\textcolor{"+str(color)+"}{"+texto+"}")+"}")
 
   if Tipo == "Componente":#Si hemos identificado el elemento ingresado como un componente, entonces lo imprimimos en rojo
     if not isinstance(c_componente[0],str):#isinstance(c_componente[0],sy.core.symbol.Symbol) or isinstance(c_componente[0],sy.core.symbol.Symbol) :
-      IPython.display.display(IPython.display.Latex(r"\textcolor{"+str(color)+"}{"+sy.latex(c_componente[0])+" = "+sy.latex(Redondear(c_componente[1]))+"}"))
+      IPython.display.display("\\"+Estilo+"{"+IPython.display.Latex(r"\textcolor{"+str(color)+"}{"+sy.latex(c_componente[0])+" = "+sy.latex(Redondear(c_componente[1]))+"}")+)
     elif isinstance(c_componente[0],str):
-      IPython.display.display(IPython.display.Latex(r"\textcolor{"+str(color)+"}{"+c_componente[0]+" = "+sy.latex(Redondear(c_componente[1]))+"}"))
+      IPython.display.display("\\"+Estilo+"{"+IPython.display.Latex(r"\textcolor{"+str(color)+"}{"+c_componente[0]+" = "+sy.latex(Redondear(c_componente[1]))+"}")+"}")
   #Código para actualizar valores: if isinstance(element[1], sy.Expr):element = [element[0],element[1].subs(c_componente[0],c_componente[1])]
 
 
@@ -43,15 +54,13 @@ def E(expr,color = "red"):
   DataRealSymbolList = []#Guarda en formato symbolo todos los Datos
   for element in DatosList:
     if (element[1] != None) :
-      if isinstance(element[1],sy.Float) or isinstance(element[1],float) or isinstance(element[1],int) or isinstance(element[1],sy.core.numbers.Integer):
-
-        word = "" 
-        for letra in sy.latex(Redondear(element[1])):
-          if letra == " ":
-            word = word+"~"
-          else:
-            word = word+letra
-        DataRealSymbolList.append([element[0],sy.symbols("("+word+")")])
+      word = "" #if isinstance(element[1],sy.Float) or isinstance(element[1],float) or isinstance(element[1],int) or isinstance(element[1],sy.core.numbers.Integer):
+      for letra in sy.latex(Redondear(element[1])):
+        if letra == " ":
+          word = word+"~"
+        else:
+          word = word+letra
+      DataRealSymbolList.append([element[0],sy.symbols("("+word+")")])
     else:
       #Es decir, si es un simbolo sin valor (None) o coleccion de simbolos. Entonces:
       DataRealSymbolList.append([element[0],element[0]])
@@ -85,14 +94,16 @@ def G(c_componente):#Guardar
   else:
     D(c_componente,"red")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
 
-#def A(c_componente):#Actualizar
-#  color = "red"
-#  for element in DatosList:
-#    if element[0] == c_componente[0]:
-#      #Identificamos el componente en la lista de datos guardados
-#      #Ahora actualizamos los valores
-#      E([c_componente[0],c_componente[1]],color)
-#      #D([c_componente[0],E(c_componente[1])],color)
-#      #D([c_componente[0],element[1].subs(DatosList)],color)
-#      element[1] = element[1].subs(DatosList)
-#      return element#Sistema por Artemio Araya :)
+def A(c_componente):#Actualizar
+  color = "red"
+  for element in DatosList:
+    if element[0] == c_componente[0]:
+      #Identificamos el componente en la lista de datos guardados
+      #Ahora actualizamos los valores
+      D(c_componente)
+      E([c_componente[0],c_componente[1]],color)
+      D([c_componente[0],c_componente[1].subs(DatosList)],color)
+      #D([c_componente[0],E(c_componente[1])],color)
+      #D([c_componente[0],element[1].subs(DatosList)],color)
+      element[1] = element[1].subs(DatosList)
+      return element#Sistema por Artemio Araya :)
